<?php

namespace Drupal\static_builder_gatsby\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configuration form for Static Builder Gatsby.
 */
class SettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'static_builder_gatsby_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['static_builder_gatsby.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('static_builder_gatsby.settings');

    $form['node_live_options'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Options for node process (live mode)'),
      '#description' => $this->t('Options passed to node process when building a "live" release, e.g., --max_old_space_size=4096'),
      '#required' => FALSE,
      '#default_value' => $config->get('node.live.options'),
    ];

    $form['node_preview_options'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Options for node process (preview mode)'),
      '#description' => $this->t('Options passed to node process when building a "preview" release, e.g., --max_old_space_size=4096'),
      '#required' => FALSE,
      '#default_value' => $config->get('node.preview.options'),
    ];

    $form['gatsby_live_options'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Options for Gatsby process (live mode)'),
      '#description' => $this->t('Options passed to Gatsby process when building a "live" release, e.g., --prefix-paths'),
      '#required' => FALSE,
      '#default_value' => $config->get('gatsby.live.options'),
    ];

    $form['gatsby_preview_options'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Options for Gatsby process (preview mode)'),
      '#description' => $this->t('Options passed to Gatsby process when building a "preview" release, e.g., --prefix-paths'),
      '#required' => FALSE,
      '#default_value' => $config->get('gatsby.preview.options'),
    ];

    $form['delete_cache'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Delete .cache folder before and after each build'),
      '#description' => $this->t('Useful if you experience issues due to stale cached data.'),
      '#default_value' => $config->get('delete.cache'),
    ];

    $form['delete_public'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Delete public folder before and after each build'),
      '#description' => $this->t('Useful to maintain disk space under control.'),
      '#default_value' => $config->get('delete.public'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = $this->config('static_builder_gatsby.settings');
    $config
      ->set('node.live.options', $form_state->getValue('node_live_options'))
      ->set('gatsby.live.options', $form_state->getValue('gatsby_live_options'))
      ->set('node.preview.options', $form_state->getValue('node_preview_options'))
      ->set('gatsby.preview.options', $form_state->getValue('gatsby_preview_options'))
      ->set('delete.cache', $form_state->getValue('delete_cache'))
      ->set('delete.public', $form_state->getValue('delete_public'))
      ->save();

    parent::submitForm($form, $form_state);
  }

}
