<?php

namespace Drupal\static_builder_hugo\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configuration form for Static Builder Hugo.
 */
class SettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'static_builder_hugo_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['static_builder_hugo.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('static_builder_hugo.settings');

    $form['hugo_live_options'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Options for hugo process (live mode)'),
      '#description' => $this->t('Options passed to hugo process when building a "live" release, e.g., --config'),
      '#required' => FALSE,
      '#default_value' => $config->get('hugo.live.options'),
    ];

    $form['hugo_preview_options'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Options for hugo process (preview mode)'),
      '#description' => $this->t('Options passed to hugo process when building a "preview" release, e.g., --config'),
      '#required' => FALSE,
      '#default_value' => $config->get('hugo.preview.options'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = $this->config('static_builder_hugo.settings');
    $config
      ->set('hugo.live.options', $form_state->getValue('hugo_live_options'))
      ->set('hugo.preview.options', $form_state->getValue('hugo_preview_options'))
      ->save();

    parent::submitForm($form, $form_state);
  }

}
