<?php

namespace Drupal\static_build\Plugin;

use Throwable;

/**
 * Helper methods for Static Builder.
 */
class StaticBuilderHelper implements StaticBuilderHelperInterface {

  /**
   * The static builder manager.
   *
   * @var \Drupal\static_build\Plugin\StaticBuilderPluginManagerInterface
   */
  protected $staticBuilderPluginManager;

  /**
   * StaticBuilderHelper constructor.
   *
   * @param \Drupal\static_build\Plugin\StaticBuilderPluginManagerInterface $staticBuilderPluginManager
   *   The static builder manager.
   */
  public function __construct(StaticBuilderPluginManagerInterface $staticBuilderPluginManager) {
    $this->staticBuilderPluginManager = $staticBuilderPluginManager;
  }

  /**
   * {@inheritdoc}
   */
  public function getRunningBuildData(string $builderId, string $runMode): array {
    $runningBuildData = [];
    try {
      $builder = $this->staticBuilderPluginManager->getInstance([
        'plugin_id' => $builderId,
        'configuration' => ['run-mode' => $runMode],
      ]);
      $releaseManager = $builder->getReleaseManager();
      $runningBuildData = $releaseManager->getTaskSupervisor()->getOngoingReleaseTaskData($builder->getTaskId());
    }
    catch (Throwable $e) {
      // Do nothing.
    }

    return $runningBuildData;
  }

}
