<?php

namespace Drupal\static_build\Plugin;

use Drupal\Component\Plugin\PluginManagerInterface;
use Drupal\Component\Plugin\Discovery\CachedDiscoveryInterface;
use Drupal\Core\Cache\CacheableDependencyInterface;

/**
 * Typed interface for Static Builder Manager.
 */
interface StaticBuilderPluginManagerInterface extends PluginManagerInterface, CachedDiscoveryInterface, CacheableDependencyInterface {

  /**
   * {@inheritdoc}
   *
   * Wraps parent method to add typing.
   *
   * @return \Drupal\static_build\Plugin\StaticBuilderPluginInterface
   *   A newly created exporter object instance.
   *
   * @throws \Drupal\static_suite\StaticSuiteUserException
   */
  public function createInstance($plugin_id, array $configuration = []): StaticBuilderPluginInterface;

  /**
   * {@inheritdoc}
   *
   * Wraps parent method to add typing.
   *
   * @return \Drupal\static_build\Plugin\StaticBuilderPluginInterface
   *   A newly created exporter object instance, or a previously
   *   instantiated one if available.
   *
   * @throws \Drupal\Component\Plugin\Exception\PluginException
   *   If the instance cannot be created, such as if the ID is invalid.
   * @throws \Drupal\static_suite\StaticSuiteUserException
   */
  public function getInstance(array $options): StaticBuilderPluginInterface;

  /**
   * Get local definitions.
   *
   * @return array
   *   Local definitions
   */
  public function getLocalDefinitions(): array;

  /**
   * Get cloud definitions.
   *
   * @return array
   *   Cloud definitions
   */
  public function getCloudDefinitions(): array;

}
