<?php

namespace Drupal\static_deployer_s3\Plugin\static_deploy\StaticDeployer;

use Asilgag\AWS\S3\AwsS3IncrementalDeployer;
use Asilgag\AWS\S3\Logger\MultiLogger;
use Drupal\Core\Site\Settings;
use Drupal\static_build\Release\ReleaseInterface;
use Drupal\static_deploy\Plugin\StaticDeployerPluginBase;

/**
 * Provides a static deployer for S3 buckets.
 *
 * Internally, it uses aws cli to perform operations.
 *
 * @StaticDeployer(
 *  id = "s3",
 *  label = @Translation("AWS S3"),
 *  description = @Translation("Static Deployer for AWS S3 buckets.")
 * )
 */
class StaticDeployerS3 extends StaticDeployerPluginBase {

  /**
   * {@inheritdoc}
   *
   * Use S3SiteDeployer to handle all the logic to get incremental deploys.
   */
  public function deploy(): void {
    $multiLogger = new MultiLogger($this->releaseTask->getLogFilePath(), $this->getConf('console-output') ? TRUE : FALSE);
    $s3SiteDeployer = new AwsS3IncrementalDeployer($multiLogger);
    $s3SiteDeployer->setExcludedPaths([ReleaseInterface::TASKS_DIR . '/*']);
    $s3SiteDeployer->getAwsCli()->getAwsOptions()->add('--region ' . $this->getConf('region'));
    $s3SiteDeployer->getAwsCli()->setEnvironment('AWS_ACCESS_KEY_ID', $this->getConf('access-key'));
    $s3SiteDeployer->getAwsCli()->setEnvironment('AWS_SECRET_ACCESS_KEY', $this->getConf('secret-key'));
    $s3SiteDeployer->deploy($this->currentRelease->getDir(), $this->getConf('bucket'));
  }

  /**
   * {@inheritdoc}
   */
  public function rollback(): void {
    // No rollback possible on S3.
  }

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration(): array {
    return [
      'bucket' => $this->configFactory->get('static_deployer_s3.settings')->get('bucket'),
      'region' => $this->configFactory->get('static_deployer_s3.settings')->get('region'),
      'access-key' => Settings::get('static_deployer_s3.access_key'),
      'secret-key' => Settings::get('static_deployer_s3.secret_key'),
    ];
  }

}
