<?php

namespace Drupal\static_deploy\Plugin;

use Throwable;

/**
 * Helper methods for Static Builder.
 */
class StaticDeployerHelper implements StaticDeployerHelperInterface {

  /**
   * The static deployer manager.
   *
   * @var StaticDeployerPluginManagerInterface
   */
  protected $staticDeployerPluginManager;

  /**
   * StaticDeployerHelper constructor.
   *
   * @param StaticDeployerPluginManagerInterface $staticDeployerPluginManager
   *   The static deployer manager.
   */
  public function __construct(StaticDeployerPluginManagerInterface $staticDeployerPluginManager) {
    $this->staticDeployerPluginManager = $staticDeployerPluginManager;
  }

  /**
   * {@inheritdoc}
   */
  public function getRunningDeployData(string $deployerId, string $builderId): array {
    $runningDeployData = [];
    try {
      $deployer = $this->staticDeployerPluginManager->getInstance([
        'plugin_id' => $deployerId,
        'configuration' => ['builder-id' => $builderId],
      ]);
      $releaseManager = $deployer->getReleaseManager();
      $runningDeployData = $releaseManager->getTaskSupervisor()->getOngoingReleaseTaskData($deployer->getTaskId());
    }
    catch (Throwable $e) {
      // Do nothing.
    }
    return $runningDeployData;
  }

}
