<?php

namespace Drupal\static_deploy\Plugin;

use Drupal\Component\Plugin\ConfigurableInterface;
use Drupal\Component\Plugin\DependentPluginInterface;
use Drupal\Component\Plugin\PluginInspectionInterface;
use Drupal\static_build\Release\ReleaseManagerInterface;

/**
 * Defines an interface for Static Deployer plugins.
 */
interface StaticDeployerPluginInterface extends ConfigurableInterface, DependentPluginInterface, PluginInspectionInterface {

  public const DRUSH_ASYNC_COMMAND = 'drush static-deploy:deploy';
  public const TASK_ID = 'deploy';

  /**
   * Decides whether the process should be synchronous or not.
   *
   * It forks a new process if process is asynchronous, or calls run()
   * otherwise.
   *
   * @throws \Drupal\static_suite\StaticSuiteException
   */
  public function init();

  /**
   * Run the deploy process.
   *
   * Internally, it calls deploy() or rollback() if needed.
   *
   * @throws \Drupal\static_suite\StaticSuiteException
   */
  public function run();

  /**
   * Execute deploy operations.
   *
   * This method should be over ridden by plugins to reflect each use case.
   *
   * @throws \Drupal\static_suite\StaticSuiteException
   */
  public function deploy(): void;

  /**
   * Execute rollback operations on any failure.
   *
   * This method should be over ridden by plugins to reflect each use case.
   *
   * @throws \Drupal\static_suite\StaticSuiteException
   */
  public function rollback(): void;

  /**
   * Get a conf value.
   *
   * @param string $key
   *   The conf key to be returned.
   *
   * @return mixed|null
   *   The conf value
   */
  public function getConf(string $key);

  /**
   * Get the id of the task this deployer is running.
   *
   * All deployers execute a task that must be identified. It's id is usually
   * "deploy-{PLUGIN_ID}"
   *
   * @return string
   *   The task id
   */
  public function getTaskId(): string;

  /**
   * Get the configured release manager.
   *
   * @return \Drupal\static_build\Release\ReleaseManagerInterface
   *   The current release manager.
   *
   * @throws \Drupal\static_suite\StaticSuiteException
   */
  public function getReleaseManager(): ReleaseManagerInterface;

}
