<?php

namespace Drupal\static_export\Exporter\Data\Includes\Loader;

use Drupal\static_export\Exporter\Output\Uri\UriInterface;
use Symfony\Component\HttpFoundation\File\MimeType\MimeTypeGuesserInterface;

/**
 * The data include loader.
 */
class DataIncludeLoader implements DataIncludeLoaderInterface {

  /**
   * The mime type guesser.
   *
   * @var \Symfony\Component\HttpFoundation\File\MimeType\MimeTypeGuesserInterface
   */
  protected $mimeTypeGuesser;

  /**
   * The data include loader plugin manager.
   *
   * @var \Drupal\static_export\Exporter\Data\Includes\Loader\DataIncludeLoaderPluginManagerInterface
   */
  protected $dataIncludeLoaderPluginManager;

  /**
   * DataIncludeLoader constructor.
   *
   * @param \Symfony\Component\HttpFoundation\File\MimeType\MimeTypeGuesserInterface $mimeTypeGuesser
   *   The mime type guesser.
   * @param \Drupal\static_export\Exporter\Data\Includes\Loader\DataIncludeLoaderPluginManagerInterface $dataIncludeLoaderPluginManager
   *   The data include loader plugin manager.
   */
  public function __construct(MimeTypeGuesserInterface $mimeTypeGuesser, DataIncludeLoaderPluginManagerInterface $dataIncludeLoaderPluginManager) {
    $this->mimeTypeGuesser = $mimeTypeGuesser;
    $this->dataIncludeLoaderPluginManager = $dataIncludeLoaderPluginManager;
  }

  /**
   * {@inheritdoc}
   *
   * @throws \Drupal\Component\Plugin\Exception\PluginException
   */
  public function load(UriInterface $uri, string $mimeType = NULL): string {
    if (!$mimeType) {
      $mimeType = $this->mimeTypeGuesser->guess($uri);
    }

    $uriContents = @file_get_contents($uri);

    $definitionsByMimetype = $this->dataIncludeLoaderPluginManager->getDefinitionsByMimeType($mimeType);
    foreach ($definitionsByMimetype as $definitionByMimetype) {
      $includeLoader = $this->dataIncludeLoaderPluginManager->getInstance(['plugin_id' => $definitionByMimetype['id']]);
      $processedUriContents = $includeLoader->load($uriContents);
      if ($processedUriContents !== $uriContents) {
        return $processedUriContents;
      }
    }

    return $uriContents;
  }

}
