<?php

namespace Drupal\static_export\Exporter\Output\Uri\Resolver\PagePath;

use Drupal\Component\Plugin\Exception\PluginException;
use Drupal\static_export\Exporter\Output\Uri\UriInterface;

/**
 * URI resolver of page paths.
 */
class PagePathUriResolver implements PagePathUriResolverInterface {

  /**
   * The URI resolver for page paths.
   *
   * @var \Drupal\static_export\Exporter\Output\Uri\Resolver\PagePath\PagePathUriResolverPluginManagerInterface
   */
  protected $pagePathUriResolverPluginManager;

  /**
   * An internal cache to avoid running the resolver twice.
   *
   * @var array
   */
  protected $cache;

  /**
   * PagePathUriResolver constructor.
   *
   * @param \Drupal\static_export\Exporter\Output\Uri\Resolver\PagePath\PagePathUriResolverPluginManagerInterface $pagePathUriResolverPluginManager
   *   The URI resolver for page paths.
   */
  public function __construct(PagePathUriResolverPluginManagerInterface $pagePathUriResolverPluginManager) {
    $this->pagePathUriResolverPluginManager = $pagePathUriResolverPluginManager;
  }

  /**
   * {@inheritdoc}
   */
  public function resolve(string $pagePath, string $langcode = NULL): ?UriInterface {
    $cacheKey = $pagePath . '---' . $langcode;
    $uri = NULL;

    if (!isset($this->cache[$cacheKey])) {
      // Set default values for the cache.
      $this->cache[$cacheKey] = [
        'uri' => NULL,
        'resolver-type' => NULL,
      ];

      $definitions = $this->pagePathUriResolverPluginManager->getDefinitionsSortedByWeight();
      foreach ($definitions as $definition) {
        try {
          $resolverInstance = $this->pagePathUriResolverPluginManager->getInstance(['plugin_id' => $definition['id']]);
          $uri = $resolverInstance->resolve($pagePath, $langcode);
        }
        catch (PluginException $e) {
          continue;
        }
        if ($uri) {
          // Update cache with valid values.
          $this->cache[$cacheKey] = [
            'uri' => $uri,
            'resolver-type' => $definition['type'],
          ];
          break;
        }
      }
    }

    return $this->cache[$cacheKey]['uri'];
  }

  /**
   * {@inheritdoc}
   */
  public function isCustomPath(string $pagePath, string $langcode = NULL): bool {
    $this->resolve($pagePath, $langcode);
    $cacheKey = $pagePath . '---' . $langcode;
    return isset($this->cache[$cacheKey]) ? $this->cache[$cacheKey]['resolver-type'] === 'custom' : FALSE;
  }

}
