<?php

namespace Drupal\static_export\File\MimeType;

use Drupal\Core\File\MimeType\MimeTypeGuesser as BaseMimeTypeGuesser;
use Drupal\Core\StreamWrapper\StreamWrapperManagerInterface;
use Symfony\Component\HttpFoundation\File\MimeType\MimeTypeGuesserInterface;

/**
 * Defines a MIME type guesser for Static Export.
 */
class MimeTypeGuesser extends BaseMimeTypeGuesser {

  /**
   * The default mimeType guesser from Drupal's core.
   *
   * @var \Symfony\Component\HttpFoundation\File\MimeType\MimeTypeGuesserInterface
   */
  protected $defaultMimeTypeGuesser;

  /**
   * Constructs a MimeTypeGuesser object.
   *
   * @param \Drupal\Core\StreamWrapper\StreamWrapperManagerInterface $stream_wrapper_manager
   *   The stream wrapper manager.
   * @param \Symfony\Component\HttpFoundation\File\MimeType\MimeTypeGuesserInterface $defaultMimeTypeGuesser
   *   The default mimeType guesser from Drupal's core.
   */
  public function __construct(StreamWrapperManagerInterface $stream_wrapper_manager, MimeTypeGuesserInterface $defaultMimeTypeGuesser) {
    $this->defaultMimeTypeGuesser = $defaultMimeTypeGuesser;
    parent::__construct($stream_wrapper_manager);
  }

  /**
   * {@inheritdoc}
   */
  public function guess($path) {
    $mimetype = parent::guess($path);
    if (!$mimetype) {
      $mimetype = $this->defaultMimeTypeGuesser->guess($path);
    }
    return $mimetype;
  }

}
