<?php

namespace Drupal\static_export\StreamWrapper;

use Drupal\Core\StreamWrapper\LocalStream;
use Drupal\Core\StreamWrapper\StreamWrapperInterface;
use Drupal\Core\Url;

/**
 * Defines a static export (static://) stream wrapper class.
 *
 * Provides support for storing exported files with the Drupal file interface.
 */
class StaticStream extends LocalStream {

  /**
   * Config factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * StaticStream constructor.
   *
   * Dependency injection will not work here, since PHP doesn't give us a
   * chance to perform the injection. PHP creates the stream wrapper objects
   * automatically when certain file functions are called. Therefore we'll use
   * the \Drupal service locator.
   */
  public function __construct() {
    // phpcs:ignore
    $this->configFactory = \Drupal::service('config.factory');
  }

  /**
   * {@inheritdoc}
   */
  public static function getType() {
    return StreamWrapperInterface::LOCAL_NORMAL;
  }

  /**
   * {@inheritdoc}
   */
  public function getName() {
    return t('Static export files');
  }

  /**
   * {@inheritdoc}
   */
  public function getDescription() {
    return t('Exported files exported by Static Export module.');
  }

  /**
   * {@inheritdoc}
   */
  public function getDirectoryPath() {
    return $this->configFactory->get('static_export.settings')->get('data_dir');
  }

  /**
   * {@inheritdoc}
   */
  public function getExternalUrl() {
    $path = str_replace('\\', '/', $this->getTarget());
    return Url::fromRoute('static_export.file_viewer', ['uri_target' => $path], ['absolute' => TRUE, 'path_processing' => FALSE])->toString();
  }

}
