# Static Preview - Subset Build

It builds a small subset of contents and serves them under a `/preview` folder
 on Drupal's domain, or under a dedicated domain .

## INTRODUCTION ##
The idea behind this module is that if building a site takes much time, building
only the page we want to preview would provide feedback in much less time.

It is intended to work with any Static Builder, but it has been intensively
tested with Gatsby.

## HOW IT WORKS ##
Every time a preview is requested:
* This module checks if content has been already previewed and if that preview
  is stale. This check is done by reading a file located at
  `structure/config/preview-group.json` inside the data directory path defined
   by Static Export module.
* If that check fails, the content id is added to that `preview-group.json`
  file and a preview build is triggered. That id is removed from the
  `preview-group.json` file after 7 days of inactivity (if it hasn't been
  previewed again).
* The resulting release, located at
  `[BASE_DIRECTORY]/[BUILDER_ID]/preview/current` contains only the set of
  contents defined in `preview-group.json` (see `/admin/config/static/build`
  for more information about this path)

## INTEGRATION WITH GATSBY ##
Integration with other Static Builders should be similar, but let's see a real
example with Gatsby.

The above preview release should be served by a web server. It can be done in
two ways:
1) Using a `/preview` subdirectory inside your Drupal's domain (recommended
way):
    * Add `pathPrefix: '/preview'` to `gatsby-config.js`
    * Add `--prefix-paths` option inside "Options for Gatsby process (preview
      mode)" located at `/admin/config/static/build/gatsby`). This enables
      Gatsby to work seamlessly inside the `/preview` directory.
    * In `gatsby-node.js`, read `preview-group.json` file and filter which
      contents are built.
    * Add an Alias on your web server for the `/preview` path:
    ```
    # Example for Apache web server
    # Alias "/preview" "/var/www/my-site.com/builders/gatsby/preview/current"
    ```

2) Using a dedicated domain:
    * In gatsby-node.js, read preview-group.json file and filter which contents
      are built.
    * In your web server configuration, create a virtual host pointing to
      the preview release folder, located at
      `[BASE_DIRECTORY]/[BUILDER_ID]/preview/current`
      (see `/admin/config/static/build` for more information about this path)

## KEEP IN MIND ##
* This preview system works only with unpublished content. GraphQL can't
  obtain any preview data from a published content. This means that changes to
  published content can't be previewed.
* Since this preview system only builds a small subset of files, expect links
  to other pages to be broken.
* Consider password-protecting the resulting build, since unpublished content
  becomes available at a public url.

## INSTALLATION ##
Run `composer require drupal/static_preview_subset_build`

## REQUIREMENTS ##
It depends on Static Build module.

## CONFIGURATION ##
Available at `/admin/config/static/preview/subset-build'`
