/**
 * Show a progress bar for previews.
 */
(function (selector) {
  const PreviewStatus = {
    state: {
      percentage: 0,
      uniqueId: null,
      oursIsRunning: false,
      error: false
    },

    percentageModifTime: new Date().getTime(),

    previewData: {},

    setState: function (state) {
      if (this.state.percentage !== state.percentage) {
        this.percentageModifTime = new Date().getTime();
      }
      this.state = Object.assign(this.state, state);
      this.render();
    },

    init: function (selector) {
      this.progressContainer = document.querySelector(selector + ' .progress');
      this.progressBar = document.querySelector(selector + ' .progress__bar');
      this.progressDescription = document.querySelector(
        selector + ' .progress__description'
      );
      this.progressPercentage = document.querySelector(
        selector + ' .progress__percentage'
      );
      this.errorBlock = document.querySelector(selector + ' .messages--error');
      this.previewData = JSON.parse(
        document.querySelector(selector + ' .progress-data').innerHTML
      );

      this.startPulling();
    },

    startPulling: function () {
      this.intervalId = setInterval(this.fetchStatus.bind(this), 1000);
    },

    stopPulling: function () {
      clearInterval(this.intervalId);
      this.setState({percentage: 0, uniqueId: null});
    },

    fetchStatus: function () {
      fetch('/admin/static/build/releases/running-percentage/preview')
        .then(response => response.json())
        .then(status => {
          let visualPercentage;
          if (
            this.state.oursIsRunning &&
            this.state.percentage !== 0 &&
            this.state.percentage !== 100 &&
            status.percentage === 0
          ) {
            visualPercentage = 100;
          }
          else {
            visualPercentage = status.percentage;
          }

          // If no changes in percentage happens in 60 seconds, give up and show an error.
          const now = new Date().getTime();
          if (now - this.percentageModifTime > 60 * 1000) {
            this.setState({error: true});
            this.stopPulling().bind(this);
          }
          else {
            // If we are getting built but uniqueId changes, it means that it has finished.
            // Stop everything and redirect.
            if (
              this.state.oursIsRunning &&
              status['unique-id'] !== this.state.uniqueId
            ) {
              clearInterval(this.intervalId);
              this.setState({percentage: 100, uniqueId: this.state.uniqueId});
              setTimeout(() => {
                window.location.replace(this.previewData.nodeUrl);
              }, 1000);
              return;
            }

            const state = {
              percentage: visualPercentage,
              uniqueId: status['unique-id']
            };

            // If running uniqueId is greater or the same as us, it means that we are getting built on it.
            if (
              !this.state.oursIsRunning &&
              status['unique-id'] >= this.previewData.uniqueId
            ) {
              state.oursIsRunning = true;
            }

            this.setState(state);
          }
        })
        .catch(this.stopPulling.bind(this));
    },

    render: function () {
      if (this.state.error) {
        this.errorBlock.style.display = 'block';
        this.progressContainer.classList.add('progress-inactive');
      }
      else if (this.state.uniqueId) {
        if (!this.state.oursIsRunning) {
          this.progressContainer.classList.add('progress-inactive');
          this.progressDescription.innerHTML =
            this.previewData.progressDescriptionQueue +
            ' <strong>' +
            this.state.percentage +
            '%</strong>';
          this.progressPercentage.style.display = 'none';
          this.progressPercentage.innerHTML = '0%';
          this.progressBar.style.width = 0;
        }
        else {
          this.progressContainer.classList.remove('progress-inactive');
          this.progressDescription.innerHTML = this.previewData.progressDescriptionRunning;
          this.progressPercentage.style.display = 'inline';
          this.progressPercentage.innerHTML = this.state.percentage + '%';
          this.progressBar.style.width = this.state.percentage + '%';
        }
      }
    }
  };

  PreviewStatus.init(selector);
})('#static-preview-subset-build-preview-update-progress');
