<?php

namespace Drupal\static_preview_subset_build\EventSubscriber;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\static_build\Event\StaticBuildEvent;
use Drupal\static_build\Event\StaticBuildEvents;
use Drupal\static_build\Release\Release;
use Drupal\static_export\Exporter\Output\Uri\UriFactory;
use Drupal\static_export\Exporter\Output\Uri\UriFactoryInterface;
use Drupal\static_preview_subset_build\Preview\PreviewManager;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Event subscriber for Static Build.
 */
class EventSubscriber implements EventSubscriberInterface {

  /**
   * Config factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   *   The URI factory.
   *
   * @var \Drupal\static_export\Exporter\Output\Uri\UriFactoryInterface
   */
  protected $uriFactory;

  /**
   * Constructs the subscriber.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   Config factory.
   * @param \Drupal\static_export\Exporter\Output\Uri\UriFactoryInterface $uriFactory
   *   The URI factory.
   */
  public function __construct(ConfigFactoryInterface $config_factory, UriFactoryInterface $uriFactory) {
    $this->configFactory = $config_factory;
    $this->uriFactory = $uriFactory;
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    $events[StaticBuildEvents::DATA_COPYING_END][] = ['copyPreviewGroupFile'];
    return $events;
  }

  /**
   * Reacts to a StaticExportEvents::CHECK_PARAMS_ENDS event.
   *
   * @param \Drupal\static_build\Event\StaticBuildEvent $event
   *   The Static Build event.
   *
   * @return \Drupal\static_build\Event\StaticBuildEvent
   *   The processed event.
   */
  public function copyPreviewGroupFile(StaticBuildEvent $event) {

    $staticBuilder = $event->getBuilder();

    // Copy PreviewManager::PREVIEW_GROUP_FILE_PATH if run mode is preview.
    if ($staticBuilder->getConf('run-mode') === $staticBuilder::RUN_MODE_PREVIEW) {
      $previewGroupFile =  $this->uriFactory->create(PreviewManager::PREVIEW_GROUP_FILE_PATH);
      $staticBuilder->logMessage("[" . $staticBuilder->getBuildIndex() . "] Copying $previewGroupFile to " . Release::METADATA_DIR);
      $staticBuilder->getRelease()->copyToDir($previewGroupFile, Release::METADATA_DIR);
      $staticBuilder->logMessage("[" . $staticBuilder->getBuildIndex() . "] $previewGroupFile file copied.");
    }

    return $event;
  }

}
