<?php

namespace Drupal\static_preview_subset_build\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configuration form for Static Preview - Subset Build.
 */
class SettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'static_preview_subset_build_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['static_preview_subset_build.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('static_preview_subset_build.settings');

    $form['preview_path'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Preview Path'),
      '#required' => TRUE,
      '#description' => $this->t('It must start with a leading slash. Subset builds are visible on your web server under this path, e.g.- /preview. You should configure your web server to properly serve the subset build under that path, usually with an Alias Directive if using Apache, e.g.-  Alias "/preview" "/path/to/preview/current".'),
      '#default_value' => $config->get('preview_path'),

    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    $previewPath = $form_state->getValue('preview_path');
    if (substr($previewPath, 0, 1) != '/') {
      $form_state->setErrorByName(
        'preview_path',
        $this->t('Preview Path must start with a leading slash.'));
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = $this->config('static_preview_subset_build.settings');
    $config
      ->set('preview_path', preg_replace("/\/$/", "", $form_state->getValue('preview_path')))
      ->save();

    parent::submitForm($form, $form_state);
  }

}
