<?php

namespace Drupal\static_suite\Lock;

// Use Drupal\Component\Utility\SignalHandler;.
use Drupal\Core\Database\Connection;
use Drupal\Core\Lock\DatabaseLockBackend as DatabaseLockBackendBase;
use Drupal\static_suite\Utility\SignalHandler;

/**
 * Overrides the database lock backend. This is the default backend in Drupal.
 *
 * @ingroup lock
 */
class DatabaseLockBackend extends DatabaseLockBackendBase implements LockBackendInterface {

  /**
   * {@inheritdoc}
   *
   * @todo - Remove overriding constructor once
   *   https://www.drupal.org/project/drupal/issues/3195300 is in place
   */
  public function __construct(Connection $database) {
    parent::__construct($database);

    // Register shutdown callbacks to avoid stale semaphores on CLI.
    // PCNTL extension is usually loaded in CLI environments.
    if (extension_loaded('pcntl')) {
      // Create a closure over $this->releaseAll(), because the handler defined
      // in SignalHandler::register() receives parameters that conflict with
      // parameters of $this->releaseAll().
      $release_all_closure = function () {
        $this->releaseAll();
      };

      // Define signals to be handled.
      $signals = array_filter([
        defined('SIGHUP') ? SIGHUP : NULL,
        defined('SIGINT') ? SIGINT : NULL,
        defined('SIGQUIT') ? SIGQUIT : NULL,
        defined('SIGPIPE') ? SIGPIPE : NULL,
        defined('SIGTERM') ? SIGTERM : NULL,
        defined('SIGCHLD') ? SIGCHLD : NULL,
      ]);
      foreach ($signals as $signo) {
        SignalHandler::register($signo, $release_all_closure);
      }
    }
  }

  /**
   * {@inheritdoc}
   *
   * @throws \Exception
   */
  public function acquireOrWait(string $name, float $timeout = 30.0, int $delay = 30): bool {
    return (
      $this->acquire($name, $timeout)
      || (
        !$this->wait($name, $delay)
        && $this->acquire($name, $timeout)
      )
    );
  }

  /**
   * {@inheritdoc}
   */
  public function isAcquired(string $name): bool {
    return isset($this->locks[$name]);
  }

}
