<?php

namespace Drupal\static_suite\Lock;

use Drupal\Core\Lock\LockBackendInterface as LockBackendInterfaceBase;

/**
 * Lock backend interface.
 *
 * @ingroup lock
 */
interface LockBackendInterface extends LockBackendInterfaceBase {

  /**
   * Acquires a lock or waits until it can be acquired.
   *
   * Tries to acquire a lock. If that fails, wait a short period and try again.
   *
   * @param string $name
   *   Lock name. Limit of name's length is 255 characters.
   * @param float $timeout
   *   (optional) Lock lifetime in seconds. Defaults to 30.0.
   * @param int $delay
   *   Seconds to wait for. Defaults to 30.
   *
   * @return bool
   *   True if the lock has been acquired, or false otherwise.
   */
  public function acquireOrWait(string $name, float $timeout = 30.0, int $delay = 30): bool;

  /**
   * Tells whether a lock kis already acquired.
   *
   * @param string $name
   *   Lock name. Limit of name's length is 255 characters.
   *
   * @return bool
   *   True if the lock is already acquired, or false otherwise.
   */
  public function isAcquired(string $name): bool;

}
