<?php

namespace Drupal\static_suite\Utility;

use DateTime;

/**
 * Interface for helper utilities for unique IDs.
 */
interface UniqueIdHelperInterface {

  /**
   * Generates a unique id for a exporter process.
   *
   * It is not set during Drupal's bootstrap phase, because we want this value
   * to reflect the moment at which the export() or delete() methods are called
   * (which is immediately after some data has changed on the database)
   *
   * This value can only be changed on a master export process.
   *
   * @return string
   *   A unique id.
   */
  public function generateUniqueId(): string;

  /**
   * Get default unique id.
   *
   * Returns a epoch unique id.
   *
   * @return string
   *   A unique id.
   */
  public function getDefaultUniqueId(): string;

  /**
   * Check it this is a unique id.
   *
   * @param string $uniqueId
   *   A unique id to be checked.
   *
   * @return bool
   *   True if it's a unique id.
   */
  public function isUniqueId($uniqueId): bool;

  /**
   * Get a DateTime object from a unique id.
   *
   * @param string $uniqueId
   *   A unique id.
   *
   * @return \DateTime
   *   A DateTime object.
   *
   * @throws \Drupal\static_suite\StaticSuiteException
   */
  public function getDateFromUniqueId(string $uniqueId): DateTime;

}
